@@ -1,7 +1,7 @@
 /**
   FoxyProxy
-  Copyright (C) 2006-2010 LeahScape, Inc.
-  http://foxyproxy.mozdev.org/
+  Copyright (C) 2006-#%#% LeahScape, Inc.
+  http://getfoxyproxy.org/
   eric.jung@yahoo.com
 
   This source code is released under the GPL license,
@@ -10,42 +10,28 @@
 **/
 
 // Thanks for the template, doron (http://www.nexgenmedia.net/docs/protocol/)
+Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 const kSCHEME = "proxy";
-const kPROTOCOL_NAME = "FoxyProxy Protocol";
-const kPROTOCOL_CONTRACTID = "@mozilla.org/network/protocol;1?name=" + kSCHEME;
-const kPROTOCOL_CID = Components.ID("d1362868-da85-4faa-b1bf-24bfd936b0a6");
-var CI = Components.interfaces, CC = Components.classes, CR = Components.results;
-
-const kSIMPLEURI_CONTRACTID = "@mozilla.org/network/simple-uri;1";
-const kIOSERVICE_CONTRACTID = "@mozilla.org/network/io-service;1";
-const nsISupports = Components.interfaces.nsISupports;
-const nsIIOService = Components.interfaces.nsIIOService;
-const nsIProtocolHandler = Components.interfaces.nsIProtocolHandler;
-const nsIURI = Components.interfaces.nsIURI;
-const IOS = CC[kIOSERVICE_CONTRACTID].
-        getService(nsIIOService).getProtocolHandler("file").
+const CI = Components.interfaces
+const CC = Components.classes
+const CR = Components.results;
+const IOS = CC["@mozilla.org/network/io-service;1"].
+  getService(CI.nsIIOService).getProtocolHandler("file").
         QueryInterface(CI.nsIFileProtocolHandler);
 
 function Protocol() {}
 
 Protocol.prototype = {
-  QueryInterface: function(iid) {
-    if (!iid.equals(nsIProtocolHandler) &&
-        !iid.equals(nsISupports))
-      throw Components.results.NS_ERROR_NO_INTERFACE;
-    return this;
-  },
-
   scheme: kSCHEME,
   defaultPort: -1,
-  protocolFlags: nsIProtocolHandler.URI_LOADABLE_BY_ANYONE,
+  protocolFlags: CI.nsIProtocolHandler.URI_LOADABLE_BY_ANYONE,
 
   allowPort: function(port, scheme) {
     return false;
   },
 
   newURI: function(spec, charset, baseURI) {
-    var uri = CC[kSIMPLEURI_CONTRACTID].createInstance(nsIURI);
+    var uri = CC["@mozilla.org/network/simple-uri;1"].createInstance(CI.nsIURI);
     uri.spec = spec;
     return uri;
   },
@@ -164,101 +150,49 @@ Protocol.prototype = {
       fpph = this;
     fpc.notify("proxy.scheme.warning.2", null, function() {fpph.processURI(aURI)});
     return new nsDummyChannel();
-  }
-}
+  },
 
-// BEGIN: Dummy channel implementation - thanks mark finkle and http://mxr.mozilla.org/mobile-browser/source/components/protocols/nsTelProtocolHandler.js#49
+  classID: Components.ID("{d1362868-da85-4faa-b1bf-24bfd936b0a6}"),
+  contractID: "@mozilla.org/network/protocol;1?name=" + kSCHEME,
+  classDescription: "FoxyProxy Protocol",
+  QueryInterface: XPCOMUtils.generateQI([CI.nsISupports, CI.nsIProtocolHandler])
+};
+
+// Dummy channel implementation - thanks mark finkle and http://mxr.mozilla.org/mobile-browser/source/components/protocols/nsTelProtocolHandler.js#49
 function nsDummyChannel() {}
+nsDummyChannel.prototype = {
+  QueryInterface: XPCOMUtils.generateQI([CI.nsISupports, CI.nsIChannel, CI.nsIRequest]),
+  /* nsIChannel */
+  loadAttributes: null,
+  contentLength: 0,
+  owner: null,
+  loadGroup: null,
+  notificationCallbacks: null,
+  securityInfo: null,
+  open: this._open,
+  asyncOpen: this._open,
+  asyncRead: function() {throw CR.NS_ERROR_NOT_IMPLEMENTED;},
+  /* nsIRequest */
+  isPending: function() {return true;},
+  status: CR.NS_OK,
+  cancel: function(status) {this.status = status;},
+  suspend: this._suspres,
+  resume: this._suspres,
 
-nsDummyChannel.prototype.QueryInterface =
-function bc_QueryInterface(iid) {
-  if (!iid.equals(CI.nsIChannel) && !iid.equals(CI.nsIRequest) &&
-      !iid.equals(CI.nsISupports))
-      throw CR.NS_ERROR_NO_INTERFACE;
-  return this;
-}
+  _open: function() {
+    // We don't throw this (a number, not a real 'resultcode') because it
+    // upsets xpconnect if we do (error in the js console).
+    Components.returnCode = CR.NS_ERROR_NO_CONTENT;
+  },
 
-/* nsIChannel */
-nsDummyChannel.prototype.loadAttributes = null;
-nsDummyChannel.prototype.contentLength = 0;
-nsDummyChannel.prototype.owner = null;
-nsDummyChannel.prototype.loadGroup = null;
-nsDummyChannel.prototype.notificationCallbacks = null;
-nsDummyChannel.prototype.securityInfo = null;
-
-nsDummyChannel.prototype.open =
-nsDummyChannel.prototype.asyncOpen =
-function bc_open(observer, ctxt) {
-  // We don't throw this (a number, not a real 'resultcode') because it
-  // upsets xpconnect if we do (error in the js console).
-  Components.returnCode = CR.NS_ERROR_NO_CONTENT;
-}
-
-nsDummyChannel.prototype.asyncRead =
-function bc_asyncRead(listener, ctxt) {
-  throw CR.NS_ERROR_NOT_IMPLEMENTED;
-}
-
-/* nsIRequest */
-nsDummyChannel.prototype.isPending =
-function bc_isPending() {
-    return true;
-}
-
-nsDummyChannel.prototype.status = CR.NS_OK;
-
-nsDummyChannel.prototype.cancel =
-function bc_cancel(status) {
-    this.status = status;
-}
-
-nsDummyChannel.prototype.suspend =
-nsDummyChannel.prototype.resume =
-function bc_suspres() {
-    throw CR.NS_ERROR_NOT_IMPLEMENTED;
-}
-// END: Dummy channel implementation - thanks mark finkle and http://mxr.mozilla.org/mobile-browser/source/components/protocols/nsTelProtocolHandler.js#49
-
-var ProtocolFactory = new Object();
-
-ProtocolFactory.createInstance = function (outer, iid) {
-  if (outer != null)
-    throw Components.results.NS_ERROR_NO_AGGREGATION;
-  if (!iid.equals(nsIProtocolHandler) &&
-      !iid.equals(nsISupports))
-    throw Components.results.NS_ERROR_NO_INTERFACE;
-  var p = new Protocol();
-  return p;
-}
+  _suspres: function() {throw CR.NS_ERROR_NOT_IMPLEMENTED;}
+};
 
 /**
- * JS XPCOM boilerplate component registration code.
+ * XPCOMUtils.generateNSGetFactory was introduced in Mozilla 2 (Firefox 4)
+ * XPCOMUtils.generateNSGetModule is for Mozilla 1.9.2 and earlier (Firefox 3.6)
  */
-var prochandler = new Object();
-
-prochandler.registerSelf = function (compMgr, fileSpec, location, type) {
-  compMgr = compMgr.QueryInterface(Components.interfaces.nsIComponentRegistrar);
-  compMgr.registerFactoryLocation(kPROTOCOL_CID,
-                                  kPROTOCOL_NAME,
-                                  kPROTOCOL_CONTRACTID,
-                                  fileSpec,
-                                  location,
-                                  type);
-}
-
-prochandler.getClassObject = function (compMgr, cid, iid) {
-  if (!cid.equals(kPROTOCOL_CID))
-    throw Components.results.NS_ERROR_NO_INTERFACE;
-
-  if (!iid.equals(Components.interfaces.nsIFactory))
-    throw Components.results.NS_ERROR_NOT_IMPLEMENTED;
-  return ProtocolFactory;
-}
-
-prochandler.canUnload = function (compMgr) {
-  return true;
-}
-
-function NSGetModule(compMgr, fileSpec){
-  return prochandler;
-}
+if (XPCOMUtils.generateNSGetFactory)
+  var NSGetFactory = XPCOMUtils.generateNSGetFactory([Protocol]);
+else
+  var NSGetModule = XPCOMUtils.generateNSGetModule([Protocol]);
