@@ -1,7 +1,7 @@
 /**
   FoxyProxy
-  Copyright (C) 2006-2009 Eric H. Jung and LeahScape, Inc.
-  http://foxyproxy.mozdev.org/
+  Copyright (C) 2006-#%#% Eric H. Jung and LeahScape, Inc.
+  http://getfoxyproxy.org/
   eric.jung@yahoo.com
 
   This source code is released under the GPL license,
@@ -61,13 +61,11 @@ var foxyproxy = {
       // Probably not necessary, but does not hurt
       this.timer = null;
       var fpc = Components.classes["@leahscape.org/foxyproxy/common;1"].getService().wrappedJSObject;
-      if (this.first) {
-        foxyproxy.fp.defaultPrefs.saveOriginals();
-        x(foxyproxy.fp.isFoxyProxySimple() ? "http://foxyproxy.mozdev.org/basic/help.html" : "http://foxyproxy.mozdev.org/help.html");
-      }
+      if (this.first)
+        x(foxyproxy.fp.isFoxyProxySimple() ? "http://getfoxyproxy.org/basic/help.html" : "http://getfoxyproxy.org/help.html");
       else
-        x(foxyproxy.fp.isFoxyProxySimple() ? "http://foxyproxy.mozdev.org/basic/releasenotes.html" :
-          "http://foxyproxy.mozdev.org/releasenotes.html");      
+        x(foxyproxy.fp.isFoxyProxySimple() ? "http://getfoxyproxy.org/basic/releasenotes.html" :
+          "http://getfoxyproxy.org/releasenotes.html");      
       function x(url) {
         fpc.openAndReuseOneTabPerURL(url);
         // Do this last so we try again next time if we failed to display now
@@ -163,6 +161,16 @@ var foxyproxy = {
     this.toggleStatusBarWidth(this.fp.statusbar.width);
     this.setMode(this.fp.mode);
     this.updateCheck.check();
+    // if os/x add label to FoxyProxy Tools menu.
+    if (Components.classes["@mozilla.org/xre/app-info;1"].getService(Components.interfaces.nsIXULRuntime).OS == "Darwin") {
+/*! begin-foxyproxy-simple
+      document.getElementById("foxyproxyMenu").setAttribute("label", this.fp.getMessage("foxyproxy.basic.label"));
+end-foxyproxy-simple !*/
+
+/*! begin-foxyproxy-standard !*/
+      document.getElementById("foxyproxyMenu").setAttribute("label", this.fp.getMessage("foxyproxy.standard.label"));
+/*! end-foxyproxy-standard !*/
+    }
   },
 
   toggleToolsMenu : function(e) {
@@ -563,6 +571,7 @@ var foxyproxy = {
   _popupShowing : 0,
 
   onSBTBClick : function(e, o) {
+    e.preventDefault(); // required in Firefox 4 to prevent default context-menu from appearing
     if (e.button==0) {
       _act(o.leftClick, e);
     }
@@ -853,7 +862,7 @@ var foxyproxy = {
                   
         _createMenuItem(submenupopup,
           this.fp.getMessage("foxyproxy.help.label"),
-          "foxyproxy.fpc.openAndReuseOneTabPerURL('http://foxyproxy.mozdev.org/" + (isFoxyProxySimple ? "basic/" : "") + "help.html');",
+          "foxyproxy.fpc.openAndReuseOneTabPerURL('http://getfoxyproxy.org/" + (isFoxyProxySimple ? "basic/" : "") + "help.html');",
           this.fp.getMessage("foxyproxy.help.accesskey"),
           this.fp.getMessage("foxyproxy.help.tooltip"));
 
